
//	New or modified code (C)2004 Jeffrey Bakker aka EvilJess <evil@damnclan.com>
//	Existing code for Unreal  Tournament 2004 Copyright  2004 Epic Games, Inc.


//	Diabolic
//	Copyright (C) 2004 Jeffrey Bakker

//	This library is free software; you can redistribute it and/or
//	modify it under the terms of the GNU Lesser General Public
//	License as published by the Free Software Foundation; either
//	version 2.1 of the License, or (at your option) any later version.

//	This library is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//	Lesser General Public License for more details.

//	You should have received a copy of the GNU Lesser General Public
//	License along with this library; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA



class BinSlayer extends ClassicSniperRifle; //ClassicSniperRifle;

#exec TEXTURE IMPORT NAME=EvilIcon  FILE=textures\EvilIcon.pcx  GROUP=Skins
#exec TEXTURE IMPORT NAME=Scope FILE=textures\Scope.pcx GROUP=Skins
#exec TEXTURE IMPORT NAME=TexDiabolic FILE=Textures\TexDiabolic.tga GROUP=Skins FLAGS=2 LODSET=LODSET_WeaponSkin

var() bool bZooming; // is it currently zooming?

// compensate for bright fog
simulated function SetZoomBlendColor(Canvas c)
{
    local Byte    val;
    local Color   clr;
    local Color   fog;

    clr.R = 255;
    clr.G = 255;
    clr.B = 255;
    clr.A = 255;

    if( Instigator.Region.Zone.bDistanceFog )
    {
        fog = Instigator.Region.Zone.DistanceFogColor;
        val = 0;
        val = Max( val, fog.R);
        val = Max( val, fog.G);
        val = Max( val, fog.B);

        if( val > 128 )
        {
            val -= 128;
            clr.R -= val;
            clr.G -= val;
            clr.B -= val;
        }
    }
    c.DrawColor = clr;
}

simulated event RenderOverlays( Canvas Canvas )
{
	local PlayerController PCtrl;
	local float Scale;

	PCtrl = PlayerController(Instigator.Controller);

	if ( LastFOV > PCtrl.DesiredFOV )
	{
		PlaySound(Sound'WeaponSounds.LightningGun.LightningZoomIn', SLOT_Misc,,,,,false);

	}
	else if ( LastFOV < PlayerController(Instigator.Controller).DesiredFOV )
	{
		PlaySound(Sound'WeaponSounds.LightningGun.LightningZoomOut', SLOT_Misc,,,,,false);
	}

	LastFOV = PCtrl.DesiredFOV;

	if ( PCtrl.DesiredFOV == PCtrl.DefaultFOV)
	{
		Super.RenderOverlays(Canvas);
		bZooming=false;

		PCtrl.MyHud.bCrosshairShow = true;
		PCtrl.MyHud.bShowWeaponInfo = True;
		PCtrl.MyHud.bShowPersonalInfo = True;
		PCtrl.MyHud.bShowPoints = True;
		PCtrl.MyHud.bShowWeaponBar = False;
	}
	else
	{
		SetZoomBlendColor(Canvas);

		PCtrl.MyHud.bCrosshairShow = False;
		PCtrl.MyHud.bShowWeaponInfo = False;
		PCtrl.MyHud.bShowPersonalInfo = False;
		PCtrl.MyHud.bShowPoints = False;
		PCtrl.MyHud.bShowWeaponBar = False;

		Canvas.Style = ERenderStyle.STY_Translucent;

		Canvas.SetPos(0,0);
		Canvas.DrawTile( FinalBlend'XGameShaders.ZoomFX.ModuNoise', Canvas.SizeX, Canvas.SizeY, 0.0, 0.0, 512, 512 );

		Scale = Canvas.ClipX/640 * 1.0; //1.5
//		Canvas.SetPos(0.5 * Canvas.ClipX - 128 * Scale, 0.5 * Canvas.ClipY - 128 * Scale );
//		Canvas.DrawIcon(Texture'Scope', Scale);
		Canvas.SetPos(0.5 * Canvas.ClipX - 64 * Scale, 0.5 * Canvas.ClipY - 64 * Scale );
		Canvas.DrawIcon(Texture'Scope', Scale*0.50);

		Canvas.SetPos(0.5 * Canvas.ClipX + 64 * Scale, 0.5 * Canvas.ClipY + 96 * Scale);
		Canvas.DrawColor.R = 255;
		Canvas.DrawColor.G = 0;
		Canvas.DrawColor.B = 0;

		Scale = PCtrl.DefaultFOV/PCtrl.DesiredFOV;

		Canvas.Font = PCtrl.MyHud.LargerFontThan(Canvas.Font);
		Canvas.bNoSmooth = false;

		Canvas.SetPos(0.5 * Canvas.ClipX + 98 * Scale, 0.5 * Canvas.ClipY + 130 * Scale);
		Canvas.DrawText(""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2));
		Canvas.SetPos(0.5 * Canvas.ClipX + 90 * Scale, 0.5 * Canvas.ClipY + 118 * Scale);
		Canvas.DrawText(""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2));

		Canvas.SetPos(102,120);
		Canvas.DrawText("(C)2004 EvilJess");
		Canvas.SetPos(102,140);
		Canvas.DrawText("www.damnclan.com");
		Canvas.SetPos(102,160);
		Canvas.DrawText(scale$"x Zoom Precision");

		Canvas.SetPos(-16,88);
		Canvas.DrawIcon(Texture'EvilIcon', 1);

		Canvas.SetPos(15,64);
		Canvas.Font = PCtrl.MyHud.LargerFontThan(Canvas.Font);
		Canvas.DrawText(ItemName);

		Canvas.SetPos(12,62);
		Canvas.DrawText(ItemName);

		bZooming = true;
	}
}

defaultproperties
{
	ItemName="Diabolic Rifle"
	FireModeClass(0)=Class'Diabolic.DiabolicFire'
	AttachmentClass=Class'Diabolic.DiabolicAttachment'

	SelectSound=Sound'NewWeaponSounds.NewSniper_load'
	SelectForce="NewSniperLoad"
	Mesh=SkeletalMesh'SniperAnims.SniperRifle_1st'
	DrawScale=0.48
	HighDetailOverlay=Combiner'UT2004Weapons.WeaponSpecMap2'

	Skins(0)=Texture'Diabolic.Skins.TexDiabolic'
	Skins(1)=Texture'newsniperrifle.1stPerson.sniper2'
//	Skins(2)=FinalBlend'XEffectMat.Shock.ShockCoilFB'

	PickupClass=None
	InventoryGroup=4
}
