
//	New or modified code (C)2004 Jeffrey Bakker aka EvilJess <evil@damnclan.com>
//	Existing code for Unreal  Tournament 2004 Copyright  2004 Epic Games, Inc.


//	Diabolic
//	Copyright (C) 2004 Jeffrey Bakker

//	This library is free software; you can redistribute it and/or
//	modify it under the terms of the GNU Lesser General Public
//	License as published by the Free Software Foundation; either
//	version 2.1 of the License, or (at your option) any later version.

//	This library is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//	Lesser General Public License for more details.

//	You should have received a copy of the GNU Lesser General Public
//	License along with this library; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA



class DiabolicProj extends Projectile;

var Effects Corona;
var xEmitter Trail;
var class<DamageType> DamageTypeHead;
var class<xEmitter> TrailClass;
var class<Effects> CoronaClass;

simulated function Destroyed()
{
	if (Trail != None)
	{
		Trail.Destroy();
	}
	if (Corona != None)
	{
		Corona.Destroy();
	}
	Super.Destroyed();
}

simulated function PostBeginPlay()
{
	Super.PostBeginPlay();

//	if ( EffectIsRelevant(vect(0,0,0),false) )

		Trail = Spawn(TrailClass,self);
		Corona = Spawn(CoronaClass,self);

	Velocity = Vector(Rotation);
	Acceleration = Velocity * 3000.0;
	Velocity *= Speed;

	if ( Level.bDropDetail )
	{
		bDynamicLight = false;
		LightType = LT_None;
	}
}

simulated function DelayedHurtRadius( float DamageAmount, float DamageRadius, class<DamageType> DamageType, float Momentum, vector HitLocation )
{
	local actor Victims;
	local float damageScale, dist;
	local vector dir;
	
	if( bHurtEntry )
		return;

	bHurtEntry = true;
	foreach VisibleCollidingActors( class 'Actor', Victims, DamageRadius, HitLocation )
	{
		// don't let blast damage affect fluid - VisibleCollisingActors doesn't really work for them - jag
		if( (Victims != self) && (Victims.Role == ROLE_Authority) && (!Victims.IsA('FluidSurfaceInfo')) )
		{
			if(Pawn(Victims) != Instigator)
			{
				dir = Victims.Location - HitLocation;
				dist = FMax(1,VSize(dir));
				dir = dir/dist; 
				damageScale = 1 - FMax(0,(dist - Victims.CollisionRadius)/DamageRadius);
				if ( DamageType.Default.bDelayedDamage && (Instigator == None) && (Pawn(Victims) != None) )
					Pawn(Victims).DelayedDamageInstigatorController = InstigatorController;
				Victims.TakeDamage
				(
					damageScale * DamageAmount,
					Instigator, 
					Victims.Location - 0.5 * (Victims.CollisionHeight + Victims.CollisionRadius) * dir,
					(damageScale * Momentum * dir),
					DamageType
				);
			}
		} 
	}
	bHurtEntry = false;
}

simulated function Explode(vector HitLocation, vector HitNormal)
{
	if( EffectIsRelevant(Location,false) ) {

		Spawn(Class'Diabolic.BinExplosionD',,, HitLocation, rotator(HitNormal));
	}
	BlowUp(HitLocation);

	Destroy();	
}

simulated function BlowUp(vector HitLocation)
{
	DelayedHurtRadius(Damage, DamageRadius, MyDamageType, MomentumTransfer, HitLocation );
	PlaySound(Sound'NewDeath.FemaleNightmare.fn_death04');
}

simulated function ClientSideTouch(Actor Other, Vector HitLocation)
{
	if(Pawn(Other) == Instigator)	return;
	if(Pawn(Other) == Owner)	return;

	Other.TakeDamage(Damage, instigator, Location, MomentumTransfer * Normal(Velocity), MyDamageType);
}

simulated function ProcessTouch(Actor Other, Vector HitLocation)
{
	local Vector X;
	local float dist;

	if(Pawn(Other) == Instigator)	return;
	if(Pawn(Other) == Owner)	return;

	X=Normal(Velocity+vect(0,0,0.5));

	if (!Other.bWorldGeometry)
	{
		if(	(Pawn(Other) != None) &&
			(Other.GetClosestBone(HitLocation,X,dist,'head',10) == 'head') )
		{
			Other.TakeDamage(Damage*3, Instigator, HitLocation, 1*X, DamageTypeHead);
		}
		else	Other.TakeDamage(Damage, Instigator, HitLocation, 1*X, MyDamageType);
	}

	Explode(HitLocation,Normal(HitLocation-Other.Location));
}

defaultproperties
{
	Speed=9110.000000
	MaxSpeed=9416.000000
	Damage=81.000000
	MomentumTransfer=45000.000000

	TrailClass=class'Diabolic.DAMNTrail' //class'GrenadeSmokeTrail'
	CoronaClass=class'Diabolic.DAMNCorona' //class'RocketCorona'

	MyDamageType=Class'Diabolic.DamTypeDiabolic'
	DamageTypeHead=Class'Diabolic.DamTypeDiabolicDecap'

	ExplosionDecal=Class'XEffects.LinkScorch'

	LightType=LT_SubtlePulse
	LightEffect=LE_FastWave
	LightBrightness=255.000000
	LightRadius=13.000000
	LightHue=169

	DrawType=DT_StaticMesh
	StaticMesh=StaticMesh'WeaponStaticMesh.FlakChunk'

	LifeSpan=6.000000
}
